/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or (at
 *  your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *  MA 02110-1301, USA.
 *
 *  Copyright © 2006 Pierre Habouzit
 */
/*
 * Copyright notice from original mutt:
 * Copyright (C) 1999-2000 Thomas Roessler <roessler@does-not-exist.org>
 *
 * This file is part of mutt-ng, see http://www.muttng.org/.
 * It's licensed under the GNU General Public License,
 * please see the file GPL in the top level source directory.
 */

#ifndef _CHARSET_H
#define _CHARSET_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <lib-lua/lib-lua.h>
#include "charset.li"

/****************************************************************************/
/* charset functions                                                        */
/****************************************************************************/

extern int Charset_is_utf8;
extern wchar_t CharsetReplacement;

void charset_initialize(void);
void charset_canonicalize(char *, ssize_t, const char *);
int charset_is_utf8(const char *s);
int charset_is_us_ascii(const char *s);

const char *charset_getfirst(const char *);


/****************************************************************************/
/* iconv-line functions                                                     */
/****************************************************************************/

#define MUTT_ICONV_ERROR  ((iconv_t)(-1))

#ifdef HAVE_ICONV_H
#  include <iconv.h>

static inline ssize_t
my_iconv(iconv_t ict, const char **in, ssize_t *il, char **out, ssize_t *ol) {
    return iconv(ict, (char **)in, (size_t*)il, out, (size_t*)ol);
}

#else
#  define iconv_t              void*
#  define iconv_open(a, b)     MUTT_ICONV_ERROR
#  define my_iconv(a,b,c,d,e)  0
#  define iconv_close(a)       0
#endif

#define M_ICONV_HOOK_FROM 1
#define M_ICONV_HOOK_TO   2

iconv_t mutt_iconv_open(const char *, const char *, int);
ssize_t mutt_iconv(iconv_t, const char **, ssize_t *, char **, ssize_t *,
                   const char **, const char *);

int mutt_convert_string(char **, const char *, const char *, int);
int mutt_convert_nonmime_string (char **);


/****************************************************************************/
/* fgetconv functions                                                       */
/****************************************************************************/

typedef struct fgetconv_t fgetconv_t;

fgetconv_t *fgetconv_open(FILE *, const char *, const char *, int);
void fgetconv_close(fgetconv_t **);

int fgetconv(fgetconv_t *);
char *fgetconvs(char *, ssize_t, fgetconv_t *);

#endif /* _CHARSET_H */
